##  Modifying To-Do Items
To edit a to-do item, hover over the to-do item you need to modify and click on the edit icon represented by a pen. This action opens an overlay where you can make your edits.
![Modifying a To-Do Item](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274766d77a441014ab0e96b77d721fca_LowRes.png)
Modifying a To-Do Item
After making the needed changes, click Save.
**Note**
In the collaboration tab of the workspace, non-admin users can also modify to-do items. However, they can only edit the ones that were created by them. For more, see [Modifying To-Do Items](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ad8677a441014bd85fc1784a4ff30__modifying_to-do_items).
**Note**
Information
  * Bulk operations are not supported in the user interface, but they can be done using the API endpoint or the iAPI. To learn more, see [To-Do API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DTo-Do "https://app.leanix.net/openapi-explorer/?urls.primaryName=To-Do").
  * Archiving or deleting a to-do item is not possible through the user interface, but it is aligned with the [fact sheet archiving or retention period](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn to archive fact sheets individually or in bulk and effortlessly view or recover archived fact sheets in SAP LeanIX.").
  * Unfinished to-dos can be deleted using endpoints.
